@@ -3,7 +3,7 @@
 from sdv.tabular.copulas import GaussianCopula
 from sdv.tabular.ctgan import CTGAN
 
-__all__ = [
+__all__ = (
     'GaussianCopula',
     'CTGAN'
-]
+)
